@@ -13,6 +13,8 @@ from python3_anticaptcha import (
 mods = ("errors", "views", "downloads", "users", "money")
 # available complaint captcha types
 complaint_types = ("image", "recaptcha")
+# availalbe queue ID's
+queue_ids = (1, 2, 5, 6, 7, 10)
 
 
 class AntiCaptchaControl:
@@ -36,9 +38,7 @@ class AntiCaptchaControl:
         Получение баланса аккаунта
         :return: Возвращает актуальный баланс
         """
-        answer = requests.post(
-            get_balance_url, json={"clientKey": self.ANTICAPTCHA_KEY}
-        )
+        answer = requests.post(get_balance_url, json={"clientKey": self.ANTICAPTCHA_KEY})
 
         return answer.json()
 
@@ -49,19 +49,17 @@ class AntiCaptchaControl:
         """
         if mode not in mods:
             raise ValueError(
-                "\nПередан неверный `mode`."
-                f"\n\tВозможные варинты: {mods}. Вы передали - `{mode}`"
-                f"\nWrong `mode` parameter. Valid params: {mods}."
-                f"\n\tYour param - `{mode}`"
+                f"\nWrong `mode` parameter. Valid params: {mods}." f"\n\tYour param - `{mode}`"
             )
         payload = {"clientKey": self.ANTICAPTCHA_KEY, "softId": softId, "mode": mode}
         answer = requests.post(get_app_stats_url, json=payload)
 
-        return answer.json()
+        if answer.text:
+            return answer.json()
+        else:
+            return {"errorId": 1}
 
-    def complaint_on_result(
-        self, reported_id: int, captcha_type: str = "image"
-    ) -> dict:
+    def complaint_on_result(self, reported_id: int, captcha_type: str = "image") -> dict:
         f"""
         Позволяет отправить жалобу на неправильно решённую капчу.
         :param reported_id: Отправляете ID капчи на которую нужно пожаловаться
@@ -71,8 +69,6 @@ class AntiCaptchaControl:
         """
         if captcha_type not in complaint_types:
             raise ValueError(
-                "\nПередан неверный `captcha_type`."
-                f"\n\tВозможные варинты: {complaint_types}. Вы передали - `{captcha_type}`"
                 f"\nWrong `captcha_type` parameter. Valid params: {complaint_types}."
                 f"\n\tYour param - `{captcha_type}`"
             )
@@ -85,7 +81,8 @@ class AntiCaptchaControl:
             answer = requests.post(incorrect_recaptcha_url, json=payload)
         return answer.json()
 
-    def get_queue_status(self, queue_id: int) -> dict:
+    @staticmethod
+    def get_queue_status(queue_id: int) -> dict:
         """
         Получение информации о загрузке очереди, в зависимости от ID очереди.
 
@@ -111,6 +108,12 @@ class AntiCaptchaControl:
         :param queue_id: Номер очереди
         :return: JSON-объект
         """
+
+        if queue_id not in queue_ids:
+            raise ValueError(
+                f"\nWrong `mode` parameter. Valid params: {queue_ids}."
+                f"\n\tYour param - `{queue_id}`"
+            )
         payload = {"queueId": queue_id}
 
         answer = requests.post(get_queue_status_url, json=payload)
@@ -152,19 +155,17 @@ class aioAntiCaptchaControl:
         """
         if mode not in mods:
             raise ValueError(
-                "\nПередан неверный `mode`."
-                f"\n\tВозможные варинты: {mods}. Вы передали - `{mode}`"
-                f"\nWrong `mode` parameter. Valid params: {mods}."
-                f"\n\tYour param - `{mode}`"
+                f"\nWrong `mode` parameter. Valid params: {mods}." f"\n\tYour param - `{mode}`"
             )
         payload = {"clientKey": self.ANTICAPTCHA_KEY, "softId": softId, "mode": mode}
         async with aiohttp.ClientSession() as session:
             async with session.post(get_app_stats_url, json=payload) as resp:
-                return await resp.json()
+                if await resp.text():
+                    return await resp.json()
+                else:
+                    return {"errorId": 1}
 
-    async def complaint_on_result(
-        self, reported_id: int, captcha_type: str = "image"
-    ) -> dict:
+    async def complaint_on_result(self, reported_id: int, captcha_type: str = "image") -> dict:
         f"""
         Позволяет отправить жалобу на неправильно решённую капчу.
         :param reported_id: Отправляете ID капчи на которую нужно пожаловаться
@@ -174,8 +175,6 @@ class aioAntiCaptchaControl:
         """
         if captcha_type not in complaint_types:
             raise ValueError(
-                "\nПередан неверный `captcha_type`."
-                f"\n\tВозможные варинты: {complaint_types}. Вы передали - `{captcha_type}`"
                 f"\nWrong `captcha_type` parameter. Valid params: {complaint_types}."
                 f"\n\tYour param - `{captcha_type}`"
             )
@@ -191,7 +190,8 @@ class aioAntiCaptchaControl:
                 async with session.post(incorrect_recaptcha_url, json=payload) as resp:
                     return await resp.json()
 
-    async def get_queue_status(self, queue_id: int) -> dict:
+    @staticmethod
+    async def get_queue_status(queue_id: int) -> dict:
         """
         Получение информации о загрузке очереди, в зависимости от ID очереди.
 
@@ -217,6 +217,11 @@ class aioAntiCaptchaControl:
         :param queue_id: Номер очереди
         :return: JSON-объект
         """
+        if queue_id not in queue_ids:
+            raise ValueError(
+                f"\nWrong `mode` parameter. Valid params: {queue_ids}."
+                f"\n\tYour param - `{queue_id}`"
+            )
         payload = {"queueId": queue_id}
 
         async with aiohttp.ClientSession() as session:
